@@ -158,4 +158,50 @@ Tom,Wright,Apple,iPhone 12`)),
 	// 		nil,
 	// 		nil,
 	// 	))
+
+	t.Run("YamlMultiDoc/Issue314", runTest(
+		[]string{"-r", "yaml", ""},
+		[]byte(`a: x
+b: foo
+---
+a: y
+c: bar
+`),
+		newline([]byte(`a: x
+b: foo
+---
+a: y
+c: bar`)),
+		nil,
+		nil,
+	))
+
+	t.Run("Issue316", runTest(
+		[]string{"-r", "json"},
+		[]byte(`{
+  "a": "alice",
+  "b": null,
+  "c": [
+    {
+      "d": 9,
+      "e": null
+    },
+    null
+  ]
+}`),
+		newline([]byte(`{
+  "a": "alice",
+  "b": null,
+  "c": [
+    {
+      "d": 9,
+      "e": null
+    },
+    null
+  ]
+}`)),
+		nil,
+		nil,
+	))
+
 }
